@@ -77,7 +77,7 @@ pkgconf_queue_compile(pkgconf_client_t *client, pkgconf_pkg_t *world, pkgconf_li
 		pkgconf_queue_t *pkgq;
 
 		pkgq = iter->data;
-		pkgconf_dependency_parse(client, world, &world->required, pkgq->package);
+		pkgconf_dependency_parse(client, world, &world->required, pkgq->package, 0);
 	}
 
 	return (world->required.head != NULL);
